@@ -3,7 +3,7 @@ package POE::Component::Server::SimpleHTTP::PreFork;
 use strict;
 use warnings;
 
-our $VERSION = '1.99_04';
+our $VERSION = '2.07_01';
 
 use POE;
 use Socket;
@@ -99,14 +99,20 @@ has 'reqcount' => (
   default   => sub { 0 },
   provides  => {
     inc => 'inc_reqcount',
-    dec => 'dec_reqcount',          
+    dec => 'dec_reqcount',
     reset => 'reset_reqcount',
   },
 );
 
+has 'ipc_glue' => (
+  is      => 'ro',
+  default => 'scbd',
+  isa     => subtype 'Str' => where { $_ =~ /^\d+$/s || length $_ == 4 },
+);
+
 sub START {
   $poe_kernel->sig( TERM => '_sig_term' );
-  $poe_kernel->sig( CHLD => '_sig_chld' );
+  #$poe_kernel->sig( CHLD => '_sig_chld' );
   return;
 }
 
@@ -118,7 +124,7 @@ event 'SHUTDOWN' => sub {
    $self->_clear_factory if $self->_factory;
 
    # Debug stuff
-   warn 'Stopped listening for new connections!' 
+   warn 'Stopped listening for new connections!'
      if POE::Component::Server::SimpleHTTP::DEBUG;
 
    my $children;
@@ -261,7 +267,7 @@ event 'start_listener' => sub {
 # Stops listening on the socket
 event 'STOPLISTEN' => sub {
    my ($kernel,$self,$session) = @_[KERNEL,OBJECT,SESSION];
-   
+
    if ( $self->is_child ) {
 
       # If we are the child then we shouldn't really stop listening.
@@ -291,7 +297,7 @@ event 'STOPLISTEN' => sub {
 
 event 'STARTLISTEN' => sub {
    my ($kernel,$self) = @_[KERNEL,OBJECT];
-   
+
    if ( $self->is_child ) {
 
       # If we are the child then we can't really create a new SOCKETFACTORY.
@@ -428,7 +434,7 @@ event 'prefork' => sub {
       my %temp;
 
 # In order to keep a pool of spare children we need to know how many spares there are.
-      $mem = tie %temp, 'IPC::Shareable', 'scbd',
+      $mem = tie %temp, 'IPC::Shareable', $self->ipc_glue,
         { 'create' => 1, 'mode' => 0600 };
       $scoreboard = \%temp;
    }
@@ -464,6 +470,7 @@ event 'prefork' => sub {
       elsif ($pid) {
 
          # We are the parent.
+         $kernel->sig_child( $pid, '_sig_chld' );
          next;
       }
       else {
@@ -756,6 +763,7 @@ event '_sig_chld' => sub {
       # we are probably in a graceful shutdown.
       $kernel->yield( 'SHUTDOWN', 'GRACEFUL' ) if $children <= 0 and !$self->_factory;
    }
+   $kernel->sig_handled();
 };
 
 # Someone is asking us to quit...
@@ -902,6 +910,7 @@ POE::Component::Server::SimpleHTTP::PreFork - PreForking support for SimpleHTTP
 		'MAXSPARESERVERS'	=>	10,
 		'MAXCLIENTS'		=>	256,
 		'STARTSERVERS'		=>	10,
+		'IPC_GLUE'		=>	'uniq',
 	) or die 'Unable to create the HTTP Server';
 
 =head1 ABSTRACT
@@ -943,6 +952,14 @@ POE::Component::Server::SimpleHTTP::PreFork - PreForking support for SimpleHTTP
 	connections, ldap connects, etc). These events will never be called for the
 	parent.
 
+=item C<IPC_GLUE>
+
+	A string containing either an integer or 4 characters specifying the key/glue
+	for the underlying parent/child IPC communication.
+	Running multiple instances of POE::Component::Server::SimpleHTTP::PreFork
+	on the same host without using this option with different values
+	almost guarantees some chaos.
+
 =back
 
 =head2 New Events
